# awesome-caching

Inspired by [flask-caching](https://github.com/sh4nks/flask-caching)

## What's new

### The State of Art caching
Add cache key dependencies

###  Use dill as serializer
Use dill to serialize the cache object, support lambda, etc, [click here to see details](https://github.com/uqfoundation/dill).

## Python versions

Developed with python 3.6, tested against python 3.6